<?php defined('C5_EXECUTE') or die("Access Denied.");

/**
 * Yandex Money Form package for Concrete5
 * Copyright 2020, Alex Borisov. All Rights Reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2018-2020, Alex Borisov. All Rights Reserved.
 * @package Concrete\Package\ab_yandex_money_form
 */

use Concrete\Core\Page\Page;

?>

<div class="ab-yandex-money-form">
    <?php echo $form_title != '' ? '<h3>' . $form_title . '</h3>' : ''; ?>
    
    <form method="post" id="form_<?php echo $bID; ?>" action="https://money.yandex.ru/quickpay/confirm.xml">
        
        <?php
        if ($allow_user_sum) {
            echo $form->label('sum', t('Payment Value') . '<span id="payment_sum_span" class="need">' . t('Required') . '</span>');
            echo '<div class="input-group">';
                echo $form->text('sum', $payment_sum, ['maxlength' => 10]);
                echo '<div class="input-group-addon">';
                echo '&#x20bd;';
                echo '</div>';
            echo '</div>';
            echo '<p class="text-muted">' . t('Max 10 symbols') . '</p>';
        }
        else {
            echo $payment_sum != '' ? '<h4>' . $payment_sum . ' &#x20bd;</h4>' : '';
            echo $form->hidden('sum', $payment_sum);
        }
        
        echo $form->hidden('receiver', $wallet);
        echo $form->hidden('quickpay-form', $form_type);
        echo $form->hidden('targets', $payment_targets);
        
        if ($payment_formcomment) { echo $form->hidden('formcomment', $payment_formcomment); }
        if ($payment_short_dest) { echo $form->hidden('short-dest', $payment_short_dest); }
        if ($payment_label) { echo $form->hidden('label', $payment_label); }
        if ($payment_comment) { echo $form->hidden('comment', $payment_comment); }
        echo $form->hidden('need-fio', $need_fio ? 'true' : 'false');
        echo $form->hidden('need-email', $need_email ? 'true' : 'false');
        echo $form->hidden('need-phone', $need_phone ? 'true' : 'false');
        echo $form->hidden('need-address', $need_address ? 'true' : 'false');
        
        if ($success_url_page_id > 0) {
            $page = Page::getByID($success_url_page_id);
            if (!$page->isError()) {
                $success_url = $page->getCollectionLink();
                echo $form->hidden('successURL', $success_url);
            }
        }
        ?>
        
        <div class="form-group">
            <?php
            if (!$payment_ac && !$payment_pc && !$payment_mc) {
                echo $form->hidden('paymentType', 'AC');
            }
            else {
                echo '<h5>' . t('Pay with') . '</h5>';
            }
            
            if ($payment_ac) {
                echo '<div class="payment-type">';
                echo $form->radio('paymentType', 'AC', '', ['checked' => 'checked']);
                echo t('Bank Card');
                echo '</div>';
            }
            if ($payment_pc) {
                echo '<div class="payment-type">';
                echo $form->radio('paymentType', 'PC');
                echo t('Yandex.Money Wallet');
                echo '</div>';
            }
            if ($payment_mc) {
                echo '<div class="payment-type">';
                echo $form->radio('paymentType', 'MC');
                echo t('Mobile Phone Account');
                echo '</div>';
            }
            ?>
        </div>
        
        <?php if ($payment_comment) { ?>
            <div class="form-group">
                <?php
                echo $form->label('comment', t('Your Comment') . '<span class="optional">' . t('Optional') . '</span>');
                echo $form->textarea('comment', '', ['rows' => 2, 'maxlength' => 200]);
                echo '<p class="text-muted">' . t('Max 200 symbols') . '</p>';
                ?>
            </div>
        <?php } ?>
        
        <div class="form-group">
            <?php echo $form->submit('pay', $btn_text, ['id' => 'submit_' . $bID], 'btn-sm btn-primary'); ?>
        </div>
    </form>
</div>
